/*
modulo: CMESEF.C
scopo: cambio del formato del mese da numerico ad alfabetico,
       secondo i nomi specificati nel file N.DAT
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>

#define MAXBC 127

#define FILE_DATI "N.DAT"
#define NMESI 12
#define MAXLM 15


void stolower (char *s)
/* converte la stringa s in minuscolo */
{
  int i;
  for (i=0; s[i]!='\0'; i++) s[i] = tolower( s[i] );
}


void stoupper (char *s)
/* converte la stringa s in maiuscolo */
{
  int i;
  for (i=0; s[i]!='\0'; i++) s[i] = toupper( s[i] );
}


char mtab[NMESI][MAXLM+1];


int leggi_mesi (void)
{
  int n;
  FILE *afh;
  char buf[MAXBC+1];

  if ((afh=fopen(FILE_DATI,"r")) == NULL) {
    fprintf (stderr,
      "errore - impossibile aprire il file '%s' in lettura\n", FILE_DATI);
    return 0;
  }
  for (n=0; n<NMESI; n++)
  {
    if (fgets (buf, MAXBC+1, afh) == NULL)
      return n;
    if (sscanf (buf, "%s", &mtab[n]) != 1)
      return n;
  }
  fclose (afh);
  return n;
}


char *nome_mese (int n_mese)
{
  static char mese_errato[] = "(mese inesistente)";

  if (n_mese > 0 && n_mese < 13)
    return mtab[n_mese-1];
  else
    return mese_errato;
}


int main (int argc, char *argv[])
{
  char buf[MAXBC+1];
  int g, m, a;
  enum {Norm, Maiu, Minu} formato;
  int i;

  /* controllo delle opzioni */

  if (argc == 1)
    formato = Norm;
  else if (argc == 2)
  {
    if (strcmp(argv[1],"-L") == 0)
      formato = Minu;
    else if (strcmp(argv[1],"-U") == 0)
      formato = Maiu;
    else
    {
      fprintf (stderr, "errore - opzione sconosciuta (%s)\n", argv[1]);
      exit (1);
    }
  }
  else /* argc > 2 */
  {
    fprintf (stderr, "errore - e' permessa una sola opzione (-L o -U)\n");
    exit (2);
  }

  /* lettura dei nomi dei mesi */

  if (leggi_mesi() != NMESI)
  {
    fprintf (stderr, "errore - impossibile leggere tutti i nomi dei mesi\n");
    exit (3);
  }

  /* cambiamento - eventuale - dei nomi dei mesi */

  switch (formato)
  {
  case Norm:
    break;
  case Minu:
    for (i=0; i<NMESI; i++) stolower (mtab[i]);
    break;
  case Maiu:
    for (i=0; i<NMESI; i++) stoupper (mtab[i]);
    break;
  default:
    fprintf (stderr, "bug - formato impossibile\n");
    exit (4);
  }

  /* cambiamento di formato delle date lette da input */

  while (gets(buf) != NULL)
  {
    if (sscanf(buf,"%d.%d.%d",&g,&m,&a) != 3)
      fprintf (stderr, "errore - formato di data sbagliato (%s)\n", buf);
    else
      printf ("%d %s %d\n", g, nome_mese(m), a);
  }
  return 0;
}
